@@ -86,7 +86,7 @@ enum Command {
 
     #[structopt(
         about = "Create new state",
-        aliases = &["create-st", "cs"],
+        visible_aliases = &["create-st", "cs"],
         display_order(20),
     )]
     CreateState {
@@ -127,7 +127,7 @@ enum Command {
 
     #[structopt(
         about = "Delete existing state",
-        aliases = &["delete-st", "ds"],
+        visible_aliases = &["delete-st", "ds"],
         display_order(20),
     )]
     DeleteState {
@@ -137,14 +137,14 @@ enum Command {
 
     #[structopt(
         about = "List available states",
-        aliases = &["list-state", "list-st", "ls"],
+        visible_aliases = &["list-state", "list-st", "ls"],
         display_order(20),
     )]
     ListStates,
 
     #[structopt(
         about = "Show state details",
-        aliases = &["show-s", "ss"],
+        visible_aliases = &["show-s", "ss"],
         display_order(20),
     )]
     ShowState {
@@ -154,7 +154,7 @@ enum Command {
 
     #[structopt(
         about = "Register new cluster",
-        aliases = &["register-cl", "rc"],
+        visible_aliases = &["register-cl", "rc"],
         display_order(10),
     )]
     RegisterCluster {
@@ -236,7 +236,7 @@ enum Command {
 
     #[structopt(
         about = "Unregister existing cluster",
-        aliases = &["unregister-cl", "urc", "uc"],
+        visible_aliases = &["unregister-cl", "urc", "uc"],
         display_order(11),
     )]
     UnregisterCluster {
@@ -266,7 +266,7 @@ enum Command {
 
     #[structopt(
         about = "Update registered cluster",
-        aliases = &["update-cl", "upc"],
+        visible_aliases = &["update-cl", "upc"],
         display_order(12),
     )]
     UpdateCluster {
@@ -293,14 +293,14 @@ enum Command {
 
     #[structopt(
         about = "List registered clusters",
-        aliases = &["list-cluster", "list-cl", "lc"],
+        visible_aliases = &["list-cluster", "list-cl", "lc"],
         display_order(13),
     )]
     ListClusters,
 
     #[structopt(
         about = "Show registered cluster details",
-        aliases = &["show-cl", "sc"],
+        visible_aliases = &["show-cl", "sc"],
         display_order(14),
     )]
     ShowCluster {
@@ -310,7 +310,7 @@ enum Command {
 
     #[structopt(
         about = "Diagnose registered cluster for any irregularities",
-        aliases = &["diagnose-cl", "dc"],
+        visible_aliases = &["diagnose-cl", "dc"],
         display_order(15),
     )]
     DiagnoseCluster {
@@ -324,7 +324,7 @@ enum Command {
 
     #[structopt(
         about = "Manually make state available in a specified location",
-        aliases = &["add-l", "al"],
+        visible_aliases = &["add-l", "al"],
         display_order(30),
     )]
     AddLocation {
@@ -350,7 +350,7 @@ enum Command {
 
     #[structopt(
         about = "Manually make state unavailable in a specified location",
-        aliases = &["remove-l", "rem-l", "rl"],
+        visible_aliases = &["remove-l", "rem-l", "rl"],
         display_order(30),
     )]
     RemoveLocation {
@@ -385,7 +385,7 @@ enum Command {
 
     #[structopt(
         about = "Manually create new volume",
-        aliases = &["create-v", "cv"],
+        visible_aliases = &["create-v", "cv"],
         display_order(50),
         setting(clap::AppSettings::Hidden),
     )]
@@ -402,7 +402,7 @@ enum Command {
 
     #[structopt(
         about = "Manually delete existing volume",
-        aliases = &["delete-v", "dv"],
+        visible_aliases = &["delete-v", "dv"],
         display_order(50),
         setting(clap::AppSettings::Hidden),
     )]
@@ -417,7 +417,7 @@ enum Command {
 
     #[structopt(
         about = "Manually choose primary location for volume",
-        aliases = &["set-p", "sp"],
+        visible_aliases = &["set-p", "sp"],
         display_order(50),
         setting(clap::AppSettings::Hidden),
     )]
@@ -432,7 +432,7 @@ enum Command {
 
     #[structopt(
         about = "List volumes in the given state",
-        aliases = &["list-volume", "list-v", "lv"],
+        visible_aliases = &["list-volume", "list-v", "lv"],
         display_order(50),
     )]
     ListVolumes {
@@ -442,7 +442,7 @@ enum Command {
 
     #[structopt(
         about = "Show volume[s] info in the given state",
-        aliases = &["show-volume", "show-v", "sv"],
+        visible_aliases = &["show-volume", "show-v", "sv"],
         display_order(50),
     )]
     ShowVolumes {
@@ -454,7 +454,7 @@ enum Command {
 
     #[structopt(
         about = "Uninstall statehub objects from the cluster",
-        aliases = &["uninstall-sh", "us"],
+        visible_aliases = &["uninstall-sh", "us"],
         display_order(50)
     )]
     UninstallStatehub {
@@ -473,7 +473,7 @@ enum Command {
 
     #[structopt(
         about = "Save cluster token",
-        alias = "sct",
+        visible_alias = "sct",
         display_order(1000),
         setting(clap::AppSettings::Hidden)
     )]
@@ -488,7 +488,7 @@ enum Command {
 
     #[structopt(
         about = "Setup statehub configmap",
-        aliases = &["scm", "setup-cm"],
+        visible_aliases = &["scm", "setup-cm"],
         display_order(1000),
         setting(clap::AppSettings::Hidden),
     )]
@@ -515,7 +515,7 @@ enum Command {
 
     #[structopt(
         about = "Install Statehub Cluster CRD",
-        aliases = &["icc", "crd"],
+        visible_aliases = &["icc", "crd"],
         display_order(1000),
         setting(clap::AppSettings::Hidden),
     )]
@@ -537,7 +537,7 @@ enum Command {
 
     #[structopt(
         about = "Uninstall Statehub Cluster CRD",
-        aliases = &["ucc", "uncrd"],
+        visible_aliases = &["ucc", "uncrd"],
         display_order(1000),
         setting(clap::AppSettings::Hidden),
     )]
@@ -554,7 +554,7 @@ enum Command {
 
     #[structopt(
         about = "List K8s namespaces",
-        alias = "list-ns",
+        visible_alias = "list-ns",
         display_order(1000),
         setting(clap::AppSettings::Hidden)
     )]
@@ -585,7 +585,7 @@ enum Command {
 
     #[structopt(
         about = "List K8s node regions",
-        aliases = &["list-r", "lr"],
+        visible_aliases = &["list-r", "lr"],
         display_order(1000),
         setting(clap::AppSettings::Hidden),
     )]
@@ -604,7 +604,7 @@ enum Command {
 
     #[structopt(
         about = "Check for updates to statehub utility",
-        alias = "up",
+        visible_alias = "up",
         display_order(3000)
     )]
     SelfUpdate,
@@ -1112,7 +1112,7 @@ impl StateHub {
                 kubectl.cluster_name(),
                 kubectl.context(),
             ));
-            let check_cluster = kubectl.check_cluster();
+            let check_cluster = kubectl.check_cluster().await;
             futures::pin_mut!(check_cluster);
             while let Some(item) = check_cluster.next().await {
                 match item {
